# GKJH

[![builds.sr.ht status](https://builds.sr.ht/~gary-kim/gkjh.svg)](https://builds.sr.ht/~gary-kim/gkjh)

* Project Home: https://sr.ht/~gary-kim/gkjh
* Source Code: https://git.sr.ht/~gary-kim/gkjh
* Development Mailing List: https://lists.sr.ht/~gary-kim/gkjh-devel
([~gary-kim/gkjh-devel@lists.sr.ht](mailto:~gary-kim/gkjh-devel@lists.sr.ht))
* TODO: https://todo.sr.ht/~gary-kim/gkjh

Personal miscellaneous helpers for Jupyter notebooks. Used for school
assignments.

### Contributing

Currently, this is a mostly personal use library. If you are interested in
making changes, please send an email to the
[~gary-kim/gkjh-discuss@lists.sr.ht](mailto:~gary-kim/gkjh-discuss@lists.sr.ht)
mailing list first.

### License

Copyright (c) 2024 Gary Kim <<gary@garykim.dev>>

Licensed under [AGPL-3.0-or-later](./LICENSE).

May be relicensed at some point in the future.

